@@ -5,5 +5,6 @@
 from .cv_image import CVImage
 from .cv_queue import CVQueue
 from .cv_file import CVFile
-from .cv_video import CVVideo, CVVideoLoader
+from .cv_excel import CVExcel
+from .cv_video import CVVideo, CVVideoLoader, CVVideoMaker
 
