@@ -132,11 +132,11 @@ class CVVideo:
             self.video_dir + '/' + self.prefix + '_reverse_out')
         os_call(command)
 
-    def video_2_frame(self, interval=1, out_path=None):
+    def video_2_frame(self, interval=1, out_path=None, compress=False):
         if out_path is None:
             save_path = self.video_path.split('.mp4')[0] + '/'
         else:
-            save_path = out_path
+            save_path = out_path + '/'
 
         is_exists = os.path.exists(save_path)
         if not is_exists:
@@ -162,14 +162,17 @@ class CVVideo:
             if i % interval == 0:
                 # 保存图片
                 j += 1
-                save_name = save_path + str(j) + '_' + str(i) + '.png'
+                if compress:
+                    save_name = save_path + str(j) + '_' + str(i) + '.jpg'
+                else:
+                    save_name = save_path + str(j) + '_' + str(i) + '.png'
                 cv2.imwrite(save_name, frame)
                 print('image of %s is saved' % save_name)
         video_capture.release()
 
     def resize_video(self, out_size=(768, 1024), inplace=False):
 
-        out_p = self.video_path.replace(self.extension, '_{}x{}.mp4'.format(out_size[0], out_size[1]))
+        out_p = self.video_path.replace('.mp4', '_{}x{}.mp4'.format(out_size[0], out_size[1]))
         if inplace:
             os.system('mv {} {}'.format(self.video_path, out_p))
             self.video_path, out_p = out_p, self.video_path
@@ -179,9 +182,10 @@ class CVVideo:
 
         video_writer = cv2.VideoWriter(out_p, cv2.VideoWriter_fourcc(*'mp4v'), fps, out_size)
 
-        s = True
-        while s:
+        while True:
             s, img1 = cap.read()
+            if not s:
+                break
             img = cv2.resize(img1, out_size, cv2.INTER_LINEAR)
             video_writer.write(img)
         cap.release()
@@ -251,7 +255,7 @@ class CVVideo:
         reader2.release()
 
         if copy_audio:
-            os_call('ffmpeg - i {} -vn -codec copy {}'.format(self.video_path, './temp.m4a'))
+            os_call('ffmpeg -i {} -vn -codec copy {}'.format(self.video_path, './temp.m4a'))
             os_call("ffmpeg -i {} -i {} -vcodec copy -acodec copy {}".format(video_out_p, './temp.m4a',
                                                                              video_out_p.replace('_concat_out.mp4',
                                                                                                  '_concat_out_audio.mp4')))
@@ -267,6 +271,10 @@ class CVVideoLoader(object, ):
 
     def __enter__(self):
         self.cap = cv2.VideoCapture(self.video_p)
+        self.fps = self.cap.get(cv2.CAP_PROP_FPS)
+        self.size = (int(self.cap.get(cv2.CAP_PROP_FRAME_WIDTH)),
+                     int(self.cap.get(cv2.CAP_PROP_FRAME_HEIGHT)))
+        self.frames_num = self.cap.get(7)
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -277,3 +285,23 @@ class CVVideoLoader(object, ):
 
     def get(self):
         return self.cap.read()
+
+
+class CVVideoMaker(object, ):
+    @staticmethod
+    def frame_2_video(frame_path_name, frame_rate=30, output_video_path=None):
+        """
+        :param frame_path_name:  .../lb_%d_graphormer_pred.jpg
+        :param frame_rate:
+        :param output_video_path:
+        :return:
+        """
+        if not output_video_path:
+            output_video_path = str(Path(frame_path_name).parent / 'output.mp4')
+        os_call(
+            'ffmpeg -f image2 -i {} -vcodec libx264 -vf "pad=ceil(iw/2)*2:ceil(ih/2)*2" -r {} {}'.format(
+                frame_path_name, frame_rate, output_video_path))
+
+'''
+ffmpeg -y -threads 4 -start_number 0 -r 30 -i vis_results/dancecut_pare.mp4_output_temp/%06d.png -frames:v 900 -profile:v baseline -level 3.0 -c:v libx264 -pix_fmt yuv420p -an -v error -loglevel error vis_results/dancecut_pare.mp4
+'''
\ No newline at end of file
